<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Polegada</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Pé</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Milha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Milímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Metro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Quilômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Polegada Milimesimal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Milha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Jarda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Ângstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mícron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Decâmetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hectômetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigâmetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Ano-Luz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Pelo Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Laranja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Vermelho Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Verde Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Azul Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Ciano Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Amarelo Escuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Cinza Claro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Others...</source>
        <translation>Outras...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>ID da Camada Atual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Unidade de Desenho</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala do Tipo de Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Fonte de dimensão</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+100"/>
        <source>Referenced Block</source>
        <translation>Bloco referenciado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>Referência externa</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+75"/>
        <source>Pixel Unit</source>
        <translation>Pixel unidade</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>Propriedade da Referência</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>Referência externa</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Colunas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Linhas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Espaçamento de Coluna</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Espaçamento de Linha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+94"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block</source>
        <translation>Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>Tipo de Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala do tipo de linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Largura da Linha</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Cor exibida</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Ordem do Desenho</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>Parent Id</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Contorno</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Manipulador</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protegido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Selecionada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>Objeto invisível</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>Conjunto de trabalho</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Simples</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Posição do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Texto Simples</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nome da fonte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Altura do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>Largura do texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Ângulo do Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Escala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Espaçamento entre Linhas</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Alinhamento</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>Para trás</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>De cabeça para baixo</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Ver centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Ver alvo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>Camadas congeladas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>ID da camada</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Oculto</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Congelado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Guardada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Plotável</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Ajustável</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Inativo está congelado</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Ordem de tabulação</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Limites mínimo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Limites máximos</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Base de inserção</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Extensões mínimo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Extensões máximos</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Foi detectada uma referência de bloco circular (recursiva):</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nome do bloco:</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linear measurement factor</source>
        <translation>Fator de medição linear</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>Altura do texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>Distância da linha de cota</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>Tamanho das setas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>Incremento da linha de cota</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>Extensão da linha de extensionamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>Extensão da linha de deslocamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>Posição do texto vertical</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Overall scale</source>
        <translation>Escala geral</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Text horizontal</source>
        <translation>Texto horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>Tamanho do tick</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>Formato Linear</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>Lugares decimais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>Separador decimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>Supressão do zero</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>Formato angular</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>Casas decimais angulares</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>Supressão do zero angular</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>Carrapato de Arquiteto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>Cor do texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>Bloco de flechas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>Bloco de setas 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>Bloco de setas 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>Requer uma seleção</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Métrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Textura</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Pelo Bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Contínuo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Margem</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Traço-Ponto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Tracejado</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Divisor</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Pontilhado</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Oculto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Espectro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>traço ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO traço-espaço</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO Traço longo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO Traço longo-ponto duplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO Traço longo-ponto triplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO Traço longo-traço curto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO Traço longo-traço curto duplo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO traço-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO traço duplo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO traço-duplo ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO traço duplo-duplo ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO traço triplo-ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO Traço duplo-ponto triplo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Fornecimento de Água Quente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Água Quente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Linha de Gás</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Isolamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zigue Zague</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Trajetos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Linha de Cerca 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Linha de Cerca 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Ponto 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Ponto 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>Planta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>Água</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>Drenagem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drenagem Reversa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>Comunicação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>Eléctrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>Baixa Tensão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>Alta Tensão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>Potência aérea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>Impuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>Ascensão impura</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>Pela Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Pelo bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
</TS>
